containertools.delete_contents_of_container_starting_strictly_after_prolated_offset
===================================================================================

.. autofunction:: abjad.tools.containertools.delete_contents_of_container_starting_strictly_after_prolated_offset.delete_contents_of_container_starting_strictly_after_prolated_offset
